<?php
defined( 'ABSPATH' ) or die();
/**
 * @package GDC PWA
 * @version 1.0
 */
/*
Plugin Name: GDC PWA
Description: Habilita la instalación de paginas web progressive
Author: Gdc Business
Version: 1.0
Author URI: http://www.gdcapp.com/
*/

function gdcpwa_required_assets_hook() {
    
    $settings = get_option('gdcpwa_settings');

    // not supported by wp_enqueue_style
    echo '<link rel="manifest" href="/manifest.json"></link>';
    wp_enqueue_script('gdcpwa-script', plugins_url('script.js', __FILE__));
    wp_enqueue_script('gdcpwa-manup', plugins_url('manup.min.js', __FILE__));
    wp_enqueue_style('gdcpwa-style', plugins_url('style.css', __FILE__));

    wp_localize_script('gdcpwa-script', 'settings', $settings);

}

function gdcpwa_install_btn() {
    
    ?>
    <a href="#" class="gdc-install-btn gdc-hidden" id="gdc-btn-install">
        <svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="arrow-circle-down" class="svg-inline--fa fa-arrow-circle-down fa-w-16" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512">
            <path fill="#cccccc" d="M504 256c0 137-111 248-248 248S8 393 8 256 119 8 256 8s248 111 248 248zm-143.6-28.9L288 302.6V120c0-13.3-10.7-24-24-24h-16c-13.3 0-24 10.7-24 24v182.6l-72.4-75.5c-9.3-9.7-24.8-9.9-34.3-.4l-10.9 11c-9.4 9.4-9.4 24.6 0 33.9L239 404.3c9.4 9.4 24.6 9.4 33.9 0l132.7-132.7c9.4-9.4 9.4-24.6 0-33.9l-10.9-11c-9.5-9.5-25-9.3-34.3.4z"></path>
        </svg>
        <div>Instalar</div>
    </a>
    <?php
}

add_action('wp_head', 'gdcpwa_required_assets_hook');
add_action('wp_footer', 'gdcpwa_install_btn');

function gdcpwa_activate() {
    $ws_path = ABSPATH . "service-worker.js";
    $manifest_path = ABSPATH . "manifest.json";
    if (file_exists($ws_path)) {
        // should be removed by deactivate hook
        unlink($ws_path);
    }
    if (file_exists($manifest_path)) {
        // should be removed by deactivate hook
        unlink($manifest_path);
    }
    if (!copy(__DIR__ . "/service-worker.js", $ws_path)) {
        die("Ha habido un problema instalando el plugin.");
    }
    if (!copy(__DIR__ . "/manifest.json", $manifest_path)) {
        die("Ha habido un problema instalando el plugin.");
    }
    
}

function gdcpwa_deactivate() {
    $ws_path = ABSPATH . "service-worker.js";
    $manifest_path = ABSPATH . "manifest.json";
    if (file_exists($ws_path)) {
        unlink($ws_path);
    }
    if (file_exists($manifest_path)) {
        unlink($manifest_path);
    }
}

register_activation_hook(__FILE__, 'gdcpwa_activate');
register_deactivation_hook(__FILE__, 'gdcpwa_deactivate');


add_action('admin_menu', 'plugin_settings');
function plugin_settings() {
    add_menu_page('GdcPWA', 'GdcPWA', 'manage_options', 'gdcpwa-settings', 'gdcpwa_settings_page');
}

function gdcpwa_settings_page() {
    if (!current_user_can('manage_options')) {
        wp_die( __('You do not have sufficient permissions to access this page.') );
    }
    
    // Read in existing option value from database
    $settings = get_option("gdcpwa_settings");
    if (!$settings) {
        $settings = [
            'gdc_pwa_name' => ''
        ];
    }
    
    echo '<div class="wrap">';
    echo '<h2>' . __( 'Ajustes GdcPWA', 'gdcpwa-settings-header' ) . '</h2>';

    if (isset($_POST['gdc_pwa_name']) && wp_verify_nonce($_POST['gdcpwa_settings_nonce'], 'gdcpwa_save_name')) {
        
        $settings['gdc_pwa_name'] = sanitize_text_field($_POST['gdc_pwa_name']);
        $settings['gdc_pwa_scope'] = get_site_url();

        update_option("gdcpwa_settings", $settings);

        $manifest_path = ABSPATH . '/manifest.json';
        if (file_exists($manifest_path)) {
            $manifest = json_decode(file_get_contents($manifest_path), true);
            $manifest['name'] = $settings['gdc_pwa_name'];
            $manifest['scope'] = $settings['gdc_pwa_scope'];
            $manifest['start_url'] = $settings['gdc_pwa_scope'];
            $manifest['short_name'] = $settings['gdc_pwa_name'];
            $manifest['description'] = $settings['gdc_pwa_name'];

            $manifest['icons'] = [[
                "src" => plugins_url('icon.png', __FILE__),
                "sizes" => "192x192",
                "type" => "image/png"
            ]];

            file_put_contents($manifest_path, json_encode($manifest, JSON_UNESCAPED_SLASHES));
        }

        echo '<div class="updated"><p><strong>' . __('Guardado correctamente.', 'gdc-settings-saved' ) . '</strong></p></div>';
        
    }

    ?>
    

    <form name="gdcsettings-form" method="POST" action="">
        <input type="hidden" name="gdcpwa_settings_nonce" value="<?php echo wp_create_nonce('gdcpwa_save_name'); ?>" />
        <p>
            <?php echo __('Nombre PWA', 'gdcpwa-settings-name'); ?>
            <input type="text" name="gdc_pwa_name" value="<?php echo esc_attr($settings['gdc_pwa_name']); ?>" />
        </p>
        <p class="submit">
            <input type="submit" name="Submit" class="button-primary" value="<?php esc_attr_e('Guardar') ?>" />
        </p>
        
    </form>
    

    <?php
}
?>
